require("starship"):setup()

require("git"):setup()
th.git = th.git or {}
th.git.modified_sign = "M"
th.git.deleted_sign = "D"

require("dir-rules"):setup()

require("restore"):setup({
    position = { "center", w = 70, h = 40 },
    show_confirm = true,
                        })

Status:children_add(function()
    local h = cx.active.current.hovered
    local elements = {}

    local btime_formatted = nil
    if h and h.cha and h.cha.btime then
      local timestamp_num = tonumber(h.cha.btime)
      if timestamp_num and timestamp_num > 0 then
        btime_formatted = os.date("%Y-%m-%d %H:%M", math.floor(timestamp_num))
      end
    end

    local mtime_formatted = nil
    if h and h.cha and h.cha.mtime then
      local timestamp_num = tonumber(h.cha.mtime)
      if timestamp_num and timestamp_num > 0 then
        mtime_formatted = os.date("%Y-%m-%d %H:%M", math.floor(timestamp_num))
      end
    end

    if btime_formatted then
      table.insert(elements, ui.Span("B:"):fg("cyan"))
      table.insert(elements, ui.Span(btime_formatted.. " "):fg("blue"))
    end

    if mtime_formatted then
      table.insert(elements, ui.Span("M:"):fg("cyan"))
      table.insert(elements, ui.Span(mtime_formatted.. " "):fg("blue"))
    end

    return ui.Line(elements)
end, 500, Status.RIGHT)

Status:children_add(function()
    local h = cx.active.current.hovered
    if h == nil or ya.target_family() ~= "unix" then
      return ""
    end

    return ui.Line {
      ui.Span(ya.user_name(h.cha.uid) or tostring(h.cha.uid)):fg("magenta"),
      ":",
      ui.Span(ya.group_name(h.cha.gid) or tostring(h.cha.gid)):fg("magenta"),
      " ",
    }
end, 500, Status.RIGHT)

Status:children_add(function(self)
    local h = self._current.hovered
    if h and h.link_to then
      return " -> " .. tostring(h.link_to)
    else
      return ""
    end
end, 3300, Status.LEFT)


function Linemode:time_and_size()
  local time = math.floor(self._file.cha.mtime or 0)
  if time == 0 then
    time = ""
  elseif os.date("%Y", time) == os.date("%Y") then
    time = os.date("%b %d %H:%M", time)
  else
    time = os.date("%b %d  %Y", time)
  end

  local size_str
  local size = self._file:size()
  if size then
    size_str = ya.readable_size(size)
  else
    -- file count for dirs
    local folder = cx.active:history(self._file.url)
    size_str = folder and tostring(#folder.files) or "-"
  end
  local size_formatted = string.format("%6s", size_str)

  return string.format("%s  %s", time, size_formatted)
end
